<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>QEyesConfigDialog</name>
    <message>
        <location filename="../qeyesconfigdialog.cpp" line="44"/>
        <source>Appearance</source>
        <translation>Wygląd</translation>
    </message>
    <message>
        <location filename="../qeyesconfigdialog.cpp" line="50"/>
        <source>Number of eyes</source>
        <translation>Liczba oczu</translation>
    </message>
    <message>
        <location filename="../qeyesconfigdialog.cpp" line="56"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../qeyesconfigdialog.cpp" line="60"/>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <location filename="../qeyesconfigdialog.cpp" line="65"/>
        <source>Reset</source>
        <translation>Zresetuj</translation>
    </message>
    <message>
        <location filename="../qeyesconfigdialog.cpp" line="69"/>
        <source>QEyes Settings</source>
        <translation>Ustawienie QEyes</translation>
    </message>
    <message>
        <location filename="../qeyesconfigdialog.cpp" line="103"/>
        <source>QEyes default</source>
        <translation>Domyślne QEyes</translation>
    </message>
</context>
</TS>
